BrightnessPreference enum

Inheritance
Available extensions

Values

system → const BrightnessPreference
light → const BrightnessPreference
dark → const BrightnessPreference

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
isDark → bool
no setter
isLight → bool
no setter
isSystem → bool
no setter
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

brightness(BuildContext context) → Brightness
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<BrightnessPreference>
A constant List of the values in this enum, in order of their declaration.