Preferences class

Constructors

Preferences()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

clearBrightness() → Future<void>
Clears the BrightnessPreference
getBrightness(BrightnessPreference initialPreference) → Future<BrightnessPreference>
saveBrightness(BrightnessPreference preference) → Future<void>
Saves the provided brightness in SharedPreferences